#[non_exhaustive]pub enum Error<T> {
Io(T),
UnexpectedEof,
WriteZero,
InvalidInput,
NotFound,
AlreadyExists,
DirectoryIsNotEmpty,
CorruptedFileSystem,
NotEnoughSpace,
InvalidFileNameLength,
UnsupportedFileNameCharacter,
}Expand description
Error enum with all errors that can be returned by functions from this crate
Generic parameter T is a type of external error returned by the user provided storage
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Io(T)
A user provided storage instance returned an error during an input/output operation.
UnexpectedEof
A read operation cannot be completed because an end of a file has been reached prematurely.
WriteZero
A write operation cannot be completed because Write::write returned 0.
InvalidInput
A parameter was incorrect.
NotFound
A requested file or directory has not been found.
AlreadyExists
A file or a directory with the same name already exists.
DirectoryIsNotEmpty
An operation cannot be finished because a directory is not empty.
CorruptedFileSystem
File system internal structures are corrupted/invalid.
NotEnoughSpace
There is not enough free space on the storage to finish the requested operation.
InvalidFileNameLength
The provided file name is either too long or empty.
UnsupportedFileNameCharacter
The provided file name contains an invalid character.